@@ -1,5 +1,6 @@
 import requests
 import tempfile
+import platform
 from pathlib import Path
 from typing import Tuple
 from datomizer import Datomizer
@@ -46,5 +47,7 @@ def upload_dataframe(presigned_url: str, df, name: str) -> None:
 def upload_temp_file(path, presigned_url):
     with open(path, 'r') as temp_file:
         header = {"Content-Type": "text/csv"}
+        if platform.system() == 'Windows':
+            header = {"Content-Type": "application/vnd.ms-excel"}
         response = requests.put(url=presigned_url, data=temp_file, headers=header)
         Datomizer.validate_response(response, "Upload to put presigned url")
